@@ -13,10 +13,16 @@
  * function is only used when a connection is recycled after auto-open.
  */
 #include "curl-common.h"
+#include <Rconfig.h>
 
-/* defines _BIG_ENDIAN used below */
+/* Define BSWAP_32 on Big Endian systems */
 #if (defined(__sun) && defined(__SVR4))
 #include <sys/byteorder.h>
+#elif (defined(__APPLE__) && defined(__ppc__) || defined(__ppc64__))
+#include <libkern/OSByteOrder.h>
+#define BSWAP_32 OSSwapInt32
+#elif (defined(__OpenBSD__))
+#define BSWAP_32(x) swap32(x)
 #endif
 
 /* the RConnection API is experimental and subject to change */
@@ -128,7 +134,7 @@ static size_t rcurl_read(void *target, size_t sz, size_t ni, Rconnection con) {
 /* naive implementation of readLines */
 static int rcurl_fgetc(Rconnection con) {
   int x = 0;
-#ifdef _BIG_ENDIAN
+#ifdef WORDS_BIGENDIAN
   return rcurl_read(&x, 1, 1, con) ? BSWAP_32(x) : R_EOF;
 #else
   return rcurl_read(&x, 1, 1, con) ? x : R_EOF;
